@@ -1,19 +1,19 @@
 import os
 import igraph
-from geo import haversine
+from myutils import geo
 
 R = 6371000
 
 ##########################################################
 def add_lengths(g):
-    """Add length to the edges """
+    """Add length to the edges, assuming each vertex has a location"""
     if 'x' in g.vertex_attributes(): x = 'x'; y = 'y';
     else: x = 'lon'; y = 'lat';
 
     for i, e in enumerate(g.es()):
         lon1, lat1 = float(g.vs[e.source][x]), float(g.vs[e.source][y])
         lon2, lat2 = float(g.vs[e.target][x]), float(g.vs[e.target][y])
-        g.es[i]['length'] = haversine(lon1, lat1, lon2, lat2)
+        g.es[i]['length'] = geo.haversine(lon1, lat1, lon2, lat2)
     return g
 
 ##########################################################
